==> cdktf_cdktf_provider_azurerm-0.5.59-py3-none-any.whl: package/lib/media-transform.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MediaTransformConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#description MediaTransform#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#media_services_account_name MediaTransform#media_services_account_name}
    */
    readonly mediaServicesAccountName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#name MediaTransform#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#resource_group_name MediaTransform#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * output block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#output MediaTransform#output}
    */
    readonly output?: MediaTransformOutput[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#timeouts MediaTransform#timeouts}
    */
    readonly timeouts?: MediaTransformTimeouts;
}
export interface MediaTransformOutputAudioAnalyzerPreset {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#audio_analysis_mode MediaTransform#audio_analysis_mode}
    */
    readonly audioAnalysisMode?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#audio_language MediaTransform#audio_language}
    */
    readonly audioLanguage?: string;
}
export declare function mediaTransformOutputAudioAnalyzerPresetToTerraform(struct?: MediaTransformOutputAudioAnalyzerPresetOutputReference | MediaTransformOutputAudioAnalyzerPreset): any;
export declare class MediaTransformOutputAudioAnalyzerPresetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): MediaTransformOutputAudioAnalyzerPreset | undefined;
    set internalValue(value: MediaTransformOutputAudioAnalyzerPreset | undefined);
    private _audioAnalysisMode?;
    get audioAnalysisMode(): string;
    set audioAnalysisMode(value: string);
    resetAudioAnalysisMode(): void;
    get audioAnalysisModeInput(): string | undefined;
    private _audioLanguage?;
    get audioLanguage(): string;
    set audioLanguage(value: string);
    resetAudioLanguage(): void;
    get audioLanguageInput(): string | undefined;
}
export interface MediaTransformOutputBuiltinPreset {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#preset_name MediaTransform#preset_name}
    */
    readonly presetName?: string;
}
export declare function mediaTransformOutputBuiltinPresetToTerraform(struct?: MediaTransformOutputBuiltinPresetOutputReference | MediaTransformOutputBuiltinPreset): any;
export declare class MediaTransformOutputBuiltinPresetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): MediaTransformOutputBuiltinPreset | undefined;
    set internalValue(value: MediaTransformOutputBuiltinPreset | undefined);
    private _presetName?;
    get presetName(): string;
    set presetName(value: string);
    resetPresetName(): void;
    get presetNameInput(): string | undefined;
}
export interface MediaTransformOutputFaceDetectorPreset {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#analysis_resolution MediaTransform#analysis_resolution}
    */
    readonly analysisResolution?: string;
}
export declare function mediaTransformOutputFaceDetectorPresetToTerraform(struct?: MediaTransformOutputFaceDetectorPresetOutputReference | MediaTransformOutputFaceDetectorPreset): any;
export declare class MediaTransformOutputFaceDetectorPresetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): MediaTransformOutputFaceDetectorPreset | undefined;
    set internalValue(value: MediaTransformOutputFaceDetectorPreset | undefined);
    private _analysisResolution?;
    get analysisResolution(): string;
    set analysisResolution(value: string);
    resetAnalysisResolution(): void;
    get analysisResolutionInput(): string | undefined;
}
export interface MediaTransformOutputVideoAnalyzerPreset {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#audio_analysis_mode MediaTransform#audio_analysis_mode}
    */
    readonly audioAnalysisMode?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#audio_language MediaTransform#audio_language}
    */
    readonly audioLanguage?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#insights_type MediaTransform#insights_type}
    */
    readonly insightsType?: string;
}
export declare function mediaTransformOutputVideoAnalyzerPresetToTerraform(struct?: MediaTransformOutputVideoAnalyzerPresetOutputReference | MediaTransformOutputVideoAnalyzerPreset): any;
export declare class MediaTransformOutputVideoAnalyzerPresetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): MediaTransformOutputVideoAnalyzerPreset | undefined;
    set internalValue(value: MediaTransformOutputVideoAnalyzerPreset | undefined);
    private _audioAnalysisMode?;
    get audioAnalysisMode(): string;
    set audioAnalysisMode(value: string);
    resetAudioAnalysisMode(): void;
    get audioAnalysisModeInput(): string | undefined;
    private _audioLanguage?;
    get audioLanguage(): string;
    set audioLanguage(value: string);
    resetAudioLanguage(): void;
    get audioLanguageInput(): string | undefined;
    private _insightsType?;
    get insightsType(): string;
    set insightsType(value: string);
    resetInsightsType(): void;
    get insightsTypeInput(): string | undefined;
}
export interface MediaTransformOutput {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#on_error_action MediaTransform#on_error_action}
    */
    readonly onErrorAction?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#relative_priority MediaTransform#relative_priority}
    */
    readonly relativePriority?: string;
    /**
    * audio_analyzer_preset block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#audio_analyzer_preset MediaTransform#audio_analyzer_preset}
    */
    readonly audioAnalyzerPreset?: MediaTransformOutputAudioAnalyzerPreset;
    /**
    * builtin_preset block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#builtin_preset MediaTransform#builtin_preset}
    */
    readonly builtinPreset?: MediaTransformOutputBuiltinPreset;
    /**
    * face_detector_preset block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#face_detector_preset MediaTransform#face_detector_preset}
    */
    readonly faceDetectorPreset?: MediaTransformOutputFaceDetectorPreset;
    /**
    * video_analyzer_preset block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#video_analyzer_preset MediaTransform#video_analyzer_preset}
    */
    readonly videoAnalyzerPreset?: MediaTransformOutputVideoAnalyzerPreset;
}
export declare function mediaTransformOutputToTerraform(struct?: MediaTransformOutput | cdktf.IResolvable): any;
export interface MediaTransformTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#create MediaTransform#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#delete MediaTransform#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#read MediaTransform#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#update MediaTransform#update}
    */
    readonly update?: string;
}
export declare function mediaTransformTimeoutsToTerraform(struct?: MediaTransformTimeoutsOutputReference | MediaTransformTimeouts | cdktf.IResolvable): any;
export declare class MediaTransformTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param isSingleItem True if this is a block, false if it's a list
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, isSingleItem: boolean);
    get internalValue(): MediaTransformTimeouts | undefined;
    set internalValue(value: MediaTransformTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform azurerm_media_transform}
*/
export declare class MediaTransform extends cdktf.TerraformResource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform azurerm_media_transform} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options MediaTransformConfig
    */
    constructor(scope: Construct, id: string, config: MediaTransformConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get id(): string;
    private _mediaServicesAccountName?;
    get mediaServicesAccountName(): string;
    set mediaServicesAccountName(value: string);
    get mediaServicesAccountNameInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    private _output?;
    get output(): MediaTransformOutput[] | cdktf.IResolvable;
    set output(value: MediaTransformOutput[] | cdktf.IResolvable);
    resetOutput(): void;
    get outputInput(): cdktf.IResolvable | MediaTransformOutput[] | undefined;
    private _timeouts;
    get timeouts(): MediaTransformTimeoutsOutputReference;
    putTimeouts(value: MediaTransformTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): MediaTransformTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-0.6.19-py3-none-any.whl: package/lib/media-transform.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface MediaTransformConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#description MediaTransform#description}
    */
    readonly description?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#media_services_account_name MediaTransform#media_services_account_name}
    */
    readonly mediaServicesAccountName: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#name MediaTransform#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#resource_group_name MediaTransform#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * output block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#output MediaTransform#output}
    */
    readonly output?: MediaTransformOutput[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#timeouts MediaTransform#timeouts}
    */
    readonly timeouts?: MediaTransformTimeouts;
}
export interface MediaTransformOutputAudioAnalyzerPreset {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#audio_analysis_mode MediaTransform#audio_analysis_mode}
    */
    readonly audioAnalysisMode?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#audio_language MediaTransform#audio_language}
    */
    readonly audioLanguage?: string;
}
export declare function mediaTransformOutputAudioAnalyzerPresetToTerraform(struct?: MediaTransformOutputAudioAnalyzerPresetOutputReference | MediaTransformOutputAudioAnalyzerPreset): any;
export declare class MediaTransformOutputAudioAnalyzerPresetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MediaTransformOutputAudioAnalyzerPreset | undefined;
    set internalValue(value: MediaTransformOutputAudioAnalyzerPreset | undefined);
    private _audioAnalysisMode?;
    get audioAnalysisMode(): string;
    set audioAnalysisMode(value: string);
    resetAudioAnalysisMode(): void;
    get audioAnalysisModeInput(): string | undefined;
    private _audioLanguage?;
    get audioLanguage(): string;
    set audioLanguage(value: string);
    resetAudioLanguage(): void;
    get audioLanguageInput(): string | undefined;
}
export interface MediaTransformOutputBuiltinPreset {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#preset_name MediaTransform#preset_name}
    */
    readonly presetName?: string;
}
export declare function mediaTransformOutputBuiltinPresetToTerraform(struct?: MediaTransformOutputBuiltinPresetOutputReference | MediaTransformOutputBuiltinPreset): any;
export declare class MediaTransformOutputBuiltinPresetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MediaTransformOutputBuiltinPreset | undefined;
    set internalValue(value: MediaTransformOutputBuiltinPreset | undefined);
    private _presetName?;
    get presetName(): string;
    set presetName(value: string);
    resetPresetName(): void;
    get presetNameInput(): string | undefined;
}
export interface MediaTransformOutputFaceDetectorPreset {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#analysis_resolution MediaTransform#analysis_resolution}
    */
    readonly analysisResolution?: string;
}
export declare function mediaTransformOutputFaceDetectorPresetToTerraform(struct?: MediaTransformOutputFaceDetectorPresetOutputReference | MediaTransformOutputFaceDetectorPreset): any;
export declare class MediaTransformOutputFaceDetectorPresetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MediaTransformOutputFaceDetectorPreset | undefined;
    set internalValue(value: MediaTransformOutputFaceDetectorPreset | undefined);
    private _analysisResolution?;
    get analysisResolution(): string;
    set analysisResolution(value: string);
    resetAnalysisResolution(): void;
    get analysisResolutionInput(): string | undefined;
}
export interface MediaTransformOutputVideoAnalyzerPreset {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#audio_analysis_mode MediaTransform#audio_analysis_mode}
    */
    readonly audioAnalysisMode?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#audio_language MediaTransform#audio_language}
    */
    readonly audioLanguage?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#insights_type MediaTransform#insights_type}
    */
    readonly insightsType?: string;
}
export declare function mediaTransformOutputVideoAnalyzerPresetToTerraform(struct?: MediaTransformOutputVideoAnalyzerPresetOutputReference | MediaTransformOutputVideoAnalyzerPreset): any;
export declare class MediaTransformOutputVideoAnalyzerPresetOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MediaTransformOutputVideoAnalyzerPreset | undefined;
    set internalValue(value: MediaTransformOutputVideoAnalyzerPreset | undefined);
    private _audioAnalysisMode?;
    get audioAnalysisMode(): string;
    set audioAnalysisMode(value: string);
    resetAudioAnalysisMode(): void;
    get audioAnalysisModeInput(): string | undefined;
    private _audioLanguage?;
    get audioLanguage(): string;
    set audioLanguage(value: string);
    resetAudioLanguage(): void;
    get audioLanguageInput(): string | undefined;
    private _insightsType?;
    get insightsType(): string;
    set insightsType(value: string);
    resetInsightsType(): void;
    get insightsTypeInput(): string | undefined;
}
export interface MediaTransformOutput {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#on_error_action MediaTransform#on_error_action}
    */
    readonly onErrorAction?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#relative_priority MediaTransform#relative_priority}
    */
    readonly relativePriority?: string;
    /**
    * audio_analyzer_preset block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#audio_analyzer_preset MediaTransform#audio_analyzer_preset}
    */
    readonly audioAnalyzerPreset?: MediaTransformOutputAudioAnalyzerPreset;
    /**
    * builtin_preset block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#builtin_preset MediaTransform#builtin_preset}
    */
    readonly builtinPreset?: MediaTransformOutputBuiltinPreset;
    /**
    * face_detector_preset block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#face_detector_preset MediaTransform#face_detector_preset}
    */
    readonly faceDetectorPreset?: MediaTransformOutputFaceDetectorPreset;
    /**
    * video_analyzer_preset block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#video_analyzer_preset MediaTransform#video_analyzer_preset}
    */
    readonly videoAnalyzerPreset?: MediaTransformOutputVideoAnalyzerPreset;
}
export declare function mediaTransformOutputToTerraform(struct?: MediaTransformOutput | cdktf.IResolvable): any;
export interface MediaTransformTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#create MediaTransform#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#delete MediaTransform#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#read MediaTransform#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform#update MediaTransform#update}
    */
    readonly update?: string;
}
export declare function mediaTransformTimeoutsToTerraform(struct?: MediaTransformTimeoutsOutputReference | MediaTransformTimeouts | cdktf.IResolvable): any;
export declare class MediaTransformTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): MediaTransformTimeouts | undefined;
    set internalValue(value: MediaTransformTimeouts | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform azurerm_media_transform}
*/
export declare class MediaTransform extends cdktf.TerraformResource {
    static readonly tfResourceType = "azurerm_media_transform";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/r/media_transform azurerm_media_transform} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options MediaTransformConfig
    */
    constructor(scope: Construct, id: string, config: MediaTransformConfig);
    private _description?;
    get description(): string;
    set description(value: string);
    resetDescription(): void;
    get descriptionInput(): string | undefined;
    get id(): string;
    private _mediaServicesAccountName?;
    get mediaServicesAccountName(): string;
    set mediaServicesAccountName(value: string);
    get mediaServicesAccountNameInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    private _output?;
    get output(): MediaTransformOutput[] | cdktf.IResolvable;
    set output(value: MediaTransformOutput[] | cdktf.IResolvable);
    resetOutput(): void;
    get outputInput(): cdktf.IResolvable | MediaTransformOutput[] | undefined;
    private _timeouts;
    get timeouts(): MediaTransformTimeoutsOutputReference;
    putTimeouts(value: MediaTransformTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): MediaTransformTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
